@@ -229,6 +229,7 @@ class AwsCdkConstructLibrary(
         workflow_runs_on: typing.Optional[typing.Sequence[builtins.str]] = None,
         name: builtins.str,
         commit_generated: typing.Optional[builtins.bool] = None,
+        git_options: typing.Optional[typing.Union[_projen_04054675.GitOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         logging: typing.Optional[typing.Union[_projen_04054675.LoggerOptions, typing.Dict[builtins.str, typing.Any]]] = None,
         outdir: typing.Optional[builtins.str] = None,
         parent: typing.Optional[_projen_04054675.Project] = None,
@@ -392,6 +393,7 @@ class AwsCdkConstructLibrary(
         :param workflow_runs_on: (experimental) Github Runner selection labels. Default: ["ubuntu-latest"]
         :param name: (experimental) This is the name of your project. Default: $BASEDIR
         :param commit_generated: (experimental) Whether to commit the managed files by default. Default: true
+        :param git_options: (experimental) Configuration options for git.
         :param logging: (experimental) Configure logging options such as verbosity. Default: {}
         :param outdir: (experimental) The root directory of the project. Relative to this directory, all files are synthesized. If this project has a parent, this directory is relative to the parent directory and it cannot be the same as the parent or any of it's other sub-projects. Default: "."
         :param parent: (experimental) The parent project, if this project is part of a bigger project.
@@ -557,6 +559,7 @@ class AwsCdkConstructLibrary(
             workflow_runs_on=workflow_runs_on,
             name=name,
             commit_generated=commit_generated,
+            git_options=git_options,
             logging=logging,
             outdir=outdir,
             parent=parent,
